@@ -141,11 +141,7 @@ struct _oauth_key_data_raw {
 	char ikm_key[OAUTH_KEY_SIZE+1];
 	u64bits timestamp;
 	u32bits lifetime;
-	char hkdf_hash_func[OAUTH_HASH_FUNC_SIZE+1];
 	char as_rs_alg[OAUTH_ALG_SIZE+1];
-	char as_rs_key[OAUTH_KEY_SIZE+1];
-	char auth_alg[OAUTH_ALG_SIZE+1];
-	char auth_key[OAUTH_KEY_SIZE+1];
 };
 
 typedef struct _oauth_key_data_raw oauth_key_data_raw;
