@@ -367,18 +367,20 @@ static int handle_udp_packet(dtls_listener_relay_server_type *server,
 			}
 		}
 
-		if (s && s->read_cb && sm->m.sm.nd.nbh) {
+		if(ioa_socket_check_bandwidth(s,sm->m.sm.nd.nbh,1)) {
 			s->e = ioa_eng;
-			s->read_cb(s, IOA_EV_READ, &(sm->m.sm.nd), s->read_ctx, 1);
-			ioa_network_buffer_delete(ioa_eng, sm->m.sm.nd.nbh);
-			sm->m.sm.nd.nbh = NULL;
+			if (s && s->read_cb && sm->m.sm.nd.nbh) {
+				s->read_cb(s, IOA_EV_READ, &(sm->m.sm.nd), s->read_ctx, 1);
+				ioa_network_buffer_delete(ioa_eng, sm->m.sm.nd.nbh);
+				sm->m.sm.nd.nbh = NULL;
 
-			if (ioa_socket_tobeclosed(s)) {
-				ts_ur_super_session *ss = (ts_ur_super_session *) s->session;
-				if (ss) {
-					turn_turnserver *server = (turn_turnserver *) ss->server;
-					if (server) {
-						shutdown_client_connection(server, ss, 0, "UDP packet processing error");
+				if (ioa_socket_tobeclosed(s)) {
+					ts_ur_super_session *ss = (ts_ur_super_session *) s->session;
+					if (ss) {
+						turn_turnserver *server = (turn_turnserver *) ss->server;
+						if (server) {
+							shutdown_client_connection(server, ss, 0, "UDP packet processing error");
+						}
 					}
 				}
 			}
@@ -472,7 +474,7 @@ static int create_new_connected_udp_socket(
 		dtls_listener_relay_server_type* server, ioa_socket_handle s)
 {
 
-	evutil_socket_t udp_fd = socket(s->local_addr.ss.sa_family, SOCK_DGRAM, 0);
+	evutil_socket_t udp_fd = socket(s->local_addr.ss.sa_family, CLIENT_DGRAM_SOCKET_TYPE, CLIENT_DGRAM_SOCKET_PROTOCOL);
 	if (udp_fd < 0) {
 		perror("socket");
 		TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "%s: Cannot allocate new socket\n",
@@ -507,7 +509,7 @@ static int create_new_connected_udp_socket(
 	ret->local_addr_known = 1;
 	addr_cpy(&(ret->local_addr), &(s->local_addr));
 
-	if (addr_bind(udp_fd,&(s->local_addr),1) < 0) {
+	if (addr_bind(udp_fd,&(s->local_addr),1,1,UDP_SOCKET) < 0) {
 		TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR,
 				"Cannot bind new detached udp server socket to local addr\n");
 		IOA_CLOSE_SOCKET(ret);
@@ -749,7 +751,7 @@ static int create_server_socket(dtls_listener_relay_server_type* server, int rep
   {
 	  ioa_socket_raw udp_listen_fd = -1;
 
-	  udp_listen_fd = socket(server->addr.ss.sa_family, SOCK_DGRAM, 0);
+	  udp_listen_fd = socket(server->addr.ss.sa_family, CLIENT_DGRAM_SOCKET_TYPE, CLIENT_DGRAM_SOCKET_PROTOCOL);
 	  if (udp_listen_fd < 0) {
 		  perror("socket");
 		  return -1;
@@ -771,17 +773,17 @@ static int create_server_socket(dtls_listener_relay_server_type* server, int rep
 		  int addr_bind_cycle = 0;
 		  retry_addr_bind:
 
-		  if(addr_bind(udp_listen_fd,&server->addr,1)<0) {
+		  if(addr_bind(udp_listen_fd,&server->addr,1,1,UDP_SOCKET)<0) {
 			  perror("Cannot bind local socket to addr");
 			  char saddr[129];
 			  addr_to_string(&server->addr,(u08bits*)saddr);
-			  TURN_LOG_FUNC(TURN_LOG_LEVEL_WARNING,"Cannot bind UDP/DTLS listener socket to addr %s\n",saddr);
+			  TURN_LOG_FUNC(TURN_LOG_LEVEL_WARNING,"Cannot bind DTLS/UDP listener socket to addr %s\n",saddr);
 			  if(addr_bind_cycle++<max_binding_time) {
-				  TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO,"Trying to bind UDP/DTLS listener socket to addr %s, again...\n",saddr);
+				  TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO,"Trying to bind DTLS/UDP listener socket to addr %s, again...\n",saddr);
 				  sleep(1);
 				  goto retry_addr_bind;
 			  }
-			  TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR,"Fatal final failure: cannot bind UDP/DTLS listener socket to addr %s\n",saddr);
+			  TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR,"Fatal final failure: cannot bind DTLS/UDP listener socket to addr %s\n",saddr);
 			  exit(-1);
 		  }
 	  }
@@ -795,7 +797,7 @@ static int create_server_socket(dtls_listener_relay_server_type* server, int rep
 
   if(report_creation) {
 	  if(!turn_params.no_udp && !turn_params.no_dtls)
-		  addr_debug_print(server->verbose, &server->addr,"UDP/DTLS listener opened on");
+		  addr_debug_print(server->verbose, &server->addr,"DTLS/UDP listener opened on");
 	  else if(!turn_params.no_dtls)
 		  addr_debug_print(server->verbose, &server->addr,"DTLS listener opened on");
 	  else if(!turn_params.no_udp)
@@ -828,7 +830,7 @@ static int reopen_server_socket(dtls_listener_relay_server_type* server, evutil_
 			return create_server_socket(server,1);
 		}
 
-		ioa_socket_raw udp_listen_fd = socket(server->addr.ss.sa_family, SOCK_DGRAM, 0);
+		ioa_socket_raw udp_listen_fd = socket(server->addr.ss.sa_family, CLIENT_DGRAM_SOCKET_TYPE, CLIENT_DGRAM_SOCKET_PROTOCOL);
 		if (udp_listen_fd < 0) {
 			perror("socket");
 			FUNCEND;
@@ -849,7 +851,7 @@ static int reopen_server_socket(dtls_listener_relay_server_type* server, evutil_
 				server->ifname);
 		}
 
-		if(addr_bind(udp_listen_fd,&server->addr,1)<0) {
+		if(addr_bind(udp_listen_fd,&server->addr,1,1,UDP_SOCKET)<0) {
 			perror("Cannot bind local socket to addr");
 			char saddr[129];
 			addr_to_string(&server->addr,(u08bits*)saddr);
@@ -866,7 +868,7 @@ static int reopen_server_socket(dtls_listener_relay_server_type* server, evutil_
 
 	if (!turn_params.no_udp && !turn_params.no_dtls)
 		addr_debug_print(server->verbose, &server->addr,
-					"UDP/DTLS listener opened on ");
+					"DTLS/UDP listener opened on ");
 	else if (!turn_params.no_dtls)
 		addr_debug_print(server->verbose, &server->addr,
 					"DTLS listener opened on ");
@@ -918,7 +920,7 @@ static int init_server(dtls_listener_relay_server_type* server,
   if(ifname) STRCPY(server->ifname,ifname);
 
   if(make_ioa_addr((const u08bits*)local_address, port, &server->addr)<0) {
-	  TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR,"Cannot create a UDP/DTLS listener for address: %s\n",local_address);
+	  TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR,"Cannot create a DTLS/UDP listener for address: %s\n",local_address);
 	  return -1;
   }
 
