@@ -50,6 +50,10 @@
 #include "hiredis_libevent2.h"
 #endif
 
+#if !defined(TURN_NO_SCTP) && defined(TURN_SCTP_INCLUDE)
+#include TURN_SCTP_INCLUDE
+#endif
+
 /* Compilation test:
 #if defined(IP_RECVTTL)
 #undef IP_RECVTTL
@@ -121,8 +125,12 @@ static int is_socket_writeable(ioa_socket_handle s, size_t sz, const char *msg,
 
 		switch (s->st){
 
+		case SCTP_SOCKET:
+		case TLS_SCTP_SOCKET:
+
 		case TCP_SOCKET:
 		case TLS_SOCKET:
+
 			if (s->bev) {
 
 				struct evbuffer *evb = bufferevent_get_output(s->bev);
@@ -326,9 +334,6 @@ static void free_blist_elem(ioa_engine_handle e, stun_buffer_list_elem *buf_elem
 
 /************** ENGINE *************************/
 
-#define TURN_JIFFIE_SIZE (3)
-#define TURN_JIFFIE_LENGTH (1<<(TURN_JIFFIE_SIZE))
-
 static void timer_handler(ioa_engine_handle e, void* arg) {
 
   UNUSED_ARG(arg);
@@ -336,7 +341,7 @@ static void timer_handler(ioa_engine_handle e, void* arg) {
   _log_time_value = turn_time();
   _log_time_value_set = 1;
 
-  e->jiffie = _log_time_value >> TURN_JIFFIE_SIZE;
+  e->jiffie = _log_time_value;
 }
 
 ioa_engine_handle create_ioa_engine(super_memory_t *sm,
@@ -640,51 +645,61 @@ void delete_ioa_timer(ioa_timer_handle th)
 
 /************** SOCKETS HELPERS ***********************/
 
-static int ioa_socket_check_bandwidth(ioa_socket_handle s, size_t sz, int read)
+int ioa_socket_check_bandwidth(ioa_socket_handle s, ioa_network_buffer_handle nbh, int read)
 {
-	if(read && s && (s->e) && sz &&
-			((s->sat == CLIENT_SOCKET) || (s->sat == RELAY_SOCKET) || (s->sat == RELAY_RTCP_SOCKET)) &&
-			(s->session)) {
+	if(s && (s->e) && nbh &&
+		((s->sat == CLIENT_SOCKET) || (s->sat == RELAY_SOCKET) || (s->sat == RELAY_RTCP_SOCKET)) &&
+		(s->session)) {
+
+		size_t sz = ioa_network_buffer_get_size(nbh);
 
 		band_limit_t max_bps = s->session->bps;
 
 		if(max_bps<1)
 			return 1;
 
-		max_bps = max_bps<<TURN_JIFFIE_SIZE;
+		struct traffic_bytes *traffic = &(s->data_traffic);
+
+		if(s->sat == CLIENT_SOCKET) {
+			u08bits *buf = ioa_network_buffer_data(nbh);
+			if(stun_is_command_message_str(buf,sz)) {
+				u16bits method = stun_get_method_str(buf,sz);
+				if((method != STUN_METHOD_SEND) && (method != STUN_METHOD_DATA)) {
+					traffic = &(s->control_traffic);
+				}
+			}
+		}
 
 		band_limit_t bsz = (band_limit_t)sz;
 
 		if(s->jiffie != s->e->jiffie) {
 
 			s->jiffie = s->e->jiffie;
-			s->jiffie_bytes_read = 0;
-			s->jiffie_bytes_write = 0;
+			traffic->jiffie_bytes_read = 0;
+			traffic->jiffie_bytes_write = 0;
 
 			if(bsz > max_bps) {
-
 				return 0;
-
 			} else {
 				if(read)
-					s->jiffie_bytes_read = bsz;
+					traffic->jiffie_bytes_read = bsz;
 				else
-					s->jiffie_bytes_write = bsz;
+					traffic->jiffie_bytes_write = bsz;
 				return 1;
 			}
 		} else {
 			band_limit_t nsz;
 			if(read)
-				nsz = s->jiffie_bytes_read + bsz;
+				nsz = traffic->jiffie_bytes_read + bsz;
 			else
-				nsz = s->jiffie_bytes_write + bsz;
+				nsz = traffic->jiffie_bytes_write + bsz;
 			if(nsz > max_bps) {
 				return 0;
 			} else {
 				if(read)
-					s->jiffie_bytes_read = nsz;
+					traffic->jiffie_bytes_read = nsz;
 				else
-					s->jiffie_bytes_write = nsz;
+					traffic->jiffie_bytes_write = nsz;
 				return 1;
 			}
 		}
@@ -801,15 +816,14 @@ int set_raw_socket_tos_options(evutil_socket_t fd, int family)
 	return 0;
 }
 
-int set_socket_options_fd(evutil_socket_t fd, int tcp, int family)
+int set_socket_options_fd(evutil_socket_t fd, SOCKET_TYPE st, int family)
 {
-
 	if(fd<0)
 		return 0;
 
 	set_sock_buf_size(fd,UR_CLIENT_SOCK_BUF_SIZE);
 
-	if(tcp) {
+	if(is_tcp_socket(st)) { /* <<== FREEBSD fix */
 		struct linger so_linger;
 		so_linger.l_onoff = 1;
 		so_linger.l_linger = 0;
@@ -825,7 +839,7 @@ int set_socket_options_fd(evutil_socket_t fd, int tcp, int family)
 
 	socket_set_nonblocking(fd);
 
-	if (!tcp) {
+	if (!is_stream_socket(st)) {
 		set_raw_socket_ttl_options(fd, family);
 		set_raw_socket_tos_options(fd, family);
 
@@ -852,16 +866,26 @@ int set_socket_options_fd(evutil_socket_t fd, int tcp, int family)
 #endif
 
 	} else {
-		int flag = 1;
-		int result = setsockopt(fd, /* socket affected */
-					IPPROTO_TCP, /* set option at TCP level */
-					TCP_NODELAY, /* name of option */
-					(char*)&flag, /* value */
-					sizeof(int)); /* length of option value */
-		if (result < 0)
-			perror("TCP_NODELAY");
 
-		socket_tcp_set_keepalive(fd);
+		int flag = 1;
+
+		if(is_tcp_socket(st)) {
+			setsockopt(fd, /* socket affected */
+				IPPROTO_TCP, /* set option at TCP level */
+				TCP_NODELAY, /* name of option */
+				(char*)&flag, /* value */
+				sizeof(int)); /* length of option value */
+		} else {
+#if defined(SCTP_NODELAY)
+			setsockopt(fd, /* socket affected */
+						IPPROTO_SCTP, /* set option at SCTP level */
+						SCTP_NODELAY, /* name of option */
+						(char*)&flag, /* value */
+						sizeof(int)); /* length of option value */
+#endif
+		}
+
+		socket_tcp_set_keepalive(fd,st);
 	}
 
 	return 0;
@@ -872,7 +896,7 @@ int set_socket_options(ioa_socket_handle s)
 	if(!s || (s->parent_s))
 		return 0;
 
-	set_socket_options_fd(s->fd,((s->st == TCP_SOCKET) || (s->st == TLS_SOCKET) || (s->st == TENTATIVE_TCP_SOCKET)),s->family);
+	set_socket_options_fd(s->fd,s->st,s->family);
 
 	s->default_ttl = get_raw_socket_ttl(s->fd, s->family);
 	s->current_ttl = s->default_ttl;
@@ -885,14 +909,14 @@ int set_socket_options(ioa_socket_handle s)
 
 /* <<== Socket options helpers */
 
-ioa_socket_handle create_unbound_ioa_socket(ioa_engine_handle e, int family, SOCKET_TYPE st, SOCKET_APP_TYPE sat)
+ioa_socket_handle create_unbound_relay_ioa_socket(ioa_engine_handle e, int family, SOCKET_TYPE st, SOCKET_APP_TYPE sat)
 {
 	evutil_socket_t fd = -1;
 	ioa_socket_handle ret = NULL;
 
 	switch (st){
 	case UDP_SOCKET:
-		fd = socket(family, SOCK_DGRAM, 0);
+		fd = socket(family, RELAY_DGRAM_SOCKET_TYPE, RELAY_DGRAM_SOCKET_PROTOCOL);
 		if (fd < 0) {
 			perror("UDP socket");
 			return NULL;
@@ -900,7 +924,7 @@ ioa_socket_handle create_unbound_ioa_socket(ioa_engine_handle e, int family, SOC
 		set_sock_buf_size(fd, UR_CLIENT_SOCK_BUF_SIZE);
 		break;
 	case TCP_SOCKET:
-		fd = socket(family, SOCK_STREAM, 0);
+		fd = socket(family, RELAY_STREAM_SOCKET_TYPE, RELAY_STREAM_SOCKET_PROTOCOL);
 		if (fd < 0) {
 			perror("TCP socket");
 			return NULL;
@@ -935,7 +959,7 @@ static int bind_ioa_socket(ioa_socket_handle s, const ioa_addr* local_addr, int
 
 	if (s && s->fd >= 0 && s->e && local_addr) {
 
-		int res = addr_bind(s->fd, local_addr, reusable);
+		int res = addr_bind(s->fd, local_addr, reusable,1,s->st);
 		if (res >= 0) {
 			s->bound = 1;
 			addr_cpy(&(s->local_addr), local_addr);
@@ -1009,7 +1033,7 @@ int create_relay_ioa_sockets(ioa_engine_handle e,
 				if (port >= 0 && even_port > 0) {
 
 					IOA_CLOSE_SOCKET(*rtcp_s);
-					*rtcp_s = create_unbound_ioa_socket(e, relay_addr.ss.sa_family, UDP_SOCKET, RELAY_RTCP_SOCKET);
+					*rtcp_s = create_unbound_relay_ioa_socket(e, relay_addr.ss.sa_family, UDP_SOCKET, RELAY_RTCP_SOCKET);
 					if (*rtcp_s == NULL) {
 						perror("socket");
 						IOA_CLOSE_SOCKET(*rtp_s);
@@ -1045,7 +1069,7 @@ int create_relay_ioa_sockets(ioa_engine_handle e,
 
 				IOA_CLOSE_SOCKET(*rtp_s);
 
-				*rtp_s = create_unbound_ioa_socket(e, relay_addr.ss.sa_family,
+				*rtp_s = create_unbound_relay_ioa_socket(e, relay_addr.ss.sa_family,
 										(transport == STUN_ATTRIBUTE_TRANSPORT_TCP_VALUE) ? TCP_SOCKET : UDP_SOCKET,
 										RELAY_SOCKET);
 				if (*rtp_s == NULL) {
@@ -1217,7 +1241,7 @@ static void connect_eventcb(struct bufferevent *bev, short events, void *ptr)
 
 ioa_socket_handle ioa_create_connecting_tcp_relay_socket(ioa_socket_handle s, ioa_addr *peer_addr, connect_cb cb, void *arg)
 {
-	ioa_socket_handle ret = create_unbound_ioa_socket(s->e, s->family, s->st, TCP_RELAY_DATA_SOCKET);
+	ioa_socket_handle ret = create_unbound_relay_ioa_socket(s->e, s->family, s->st, TCP_RELAY_DATA_SOCKET);
 
 	if(!ret) {
 		return NULL;
@@ -1277,7 +1301,7 @@ ioa_socket_handle ioa_create_connecting_tcp_relay_socket(ioa_socket_handle s, io
 		 * Section 5.2 of RFC 6062 will not work correctly
 		 * for those OSes (for example, Linux pre-3.9 kernel).
 		 */
-	s->fd = socket(s->family, SOCK_STREAM, 0);
+	s->fd = socket(s->family, RELAY_STREAM_SOCKET_TYPE, RELAY_STREAM_SOCKET_PROTOCOL);
 	if (s->fd < 0) {
 		perror("TCP socket");
 		if(ret) {
@@ -1583,7 +1607,7 @@ ioa_socket_handle detach_ioa_socket(ioa_socket_handle s)
 		evutil_socket_t udp_fd = -1;
 
 		if(s->parent_s) {
-			udp_fd = socket(s->local_addr.ss.sa_family, SOCK_DGRAM, 0);
+			udp_fd = socket(s->local_addr.ss.sa_family, CLIENT_DGRAM_SOCKET_TYPE, CLIENT_DGRAM_SOCKET_PROTOCOL);
 			if (udp_fd < 0) {
 				perror("socket");
 				TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR,"%s: Cannot allocate new socket\n",__FUNCTION__);
@@ -1593,7 +1617,7 @@ ioa_socket_handle detach_ioa_socket(ioa_socket_handle s)
 				TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR,"Cannot bind udp server socket to device %s\n",(char*)(s->e->relay_ifname));
 			}
 
-			if(addr_bind(udp_fd,&(s->local_addr),1)<0) {
+			if(addr_bind(udp_fd,&(s->local_addr),1,1,UDP_SOCKET)<0) {
 				TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR,"Cannot bind new detached udp server socket to local addr\n");
 				close(udp_fd);
 				return ret;
@@ -2204,7 +2228,7 @@ static int socket_input_worker(ioa_socket_handle s)
 	  }
 	}
 
-	if(s->st == TLS_SOCKET) {
+	if((s->st == TLS_SOCKET)||(s->st == TLS_SCTP_SOCKET)) {
 #if TLS_SUPPORTED
 		SSL *ctx = bufferevent_openssl_get_ssl(s->bev);
 		if(!ctx || SSL_get_shutdown(ctx)) {
@@ -2290,6 +2314,74 @@ static int socket_input_worker(ioa_socket_handle s)
 			bufferevent_setwatermark(s->bev, EV_READ|EV_WRITE, 0, BUFFEREVENT_HIGH_WATERMARK);
 			bufferevent_enable(s->bev, EV_READ|EV_WRITE); /* Start reading. */
 		}
+	} else if(s->st == TENTATIVE_SCTP_SOCKET) {
+		EVENT_DEL(s->read_event);
+#if TLS_SUPPORTED
+		TURN_TLS_TYPE tls_type = check_tentative_tls(s->fd);
+		if(tls_type) {
+			s->st = TLS_SCTP_SOCKET;
+			if(s->ssl) {
+				TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO, "!!!%s on socket: 0x%lx, st=%d, sat=%d: ssl already exist\n", __FUNCTION__,(long)s, s->st, s->sat);
+			}
+			if(s->bev) {
+				TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO, "!!!%s on socket: 0x%lx, st=%d, sat=%d: bev already exist\n", __FUNCTION__,(long)s, s->st, s->sat);
+			}
+			switch(tls_type) {
+#if TLSv1_2_SUPPORTED
+			case TURN_TLS_v1_2:
+				if(s->e->tls_ctx_v1_2) {
+					set_socket_ssl(s,SSL_NEW(s->e->tls_ctx_v1_2));
+				}
+				break;
+#endif
+#if TLSv1_1_SUPPORTED
+			case TURN_TLS_v1_1:
+				if(s->e->tls_ctx_v1_1) {
+					set_socket_ssl(s,SSL_NEW(s->e->tls_ctx_v1_1));
+				}
+				break;
+#endif
+			case TURN_TLS_v1_0:
+				if(s->e->tls_ctx_v1_0) {
+					set_socket_ssl(s,SSL_NEW(s->e->tls_ctx_v1_0));
+				}
+				break;
+			default:
+				if(s->e->tls_ctx_ssl23) {
+					set_socket_ssl(s,SSL_NEW(s->e->tls_ctx_ssl23));
+				} else {
+					s->tobeclosed = 1;
+					return 0;
+				}
+			};
+			if(s->ssl) {
+				s->bev = bufferevent_openssl_socket_new(s->e->event_base,
+								s->fd,
+								s->ssl,
+								BUFFEREVENT_SSL_ACCEPTING,
+								TURN_BUFFEREVENTS_OPTIONS);
+				debug_ptr_add(s->bev);
+				bufferevent_setcb(s->bev, socket_input_handler_bev, socket_output_handler_bev,
+								eventcb_bev, s);
+				bufferevent_setwatermark(s->bev, EV_READ|EV_WRITE, 0, BUFFEREVENT_HIGH_WATERMARK);
+				bufferevent_enable(s->bev, EV_READ|EV_WRITE); /* Start reading. */
+			}
+		} else
+#endif //TLS_SUPPORTED
+		{
+			s->st = SCTP_SOCKET;
+			if(s->bev) {
+				TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO, "!!!%s on socket: 0x%lx, st=%d, sat=%d: bev already exist\n", __FUNCTION__,(long)s, s->st, s->sat);
+			}
+			s->bev = bufferevent_socket_new(s->e->event_base,
+						s->fd,
+						TURN_BUFFEREVENTS_OPTIONS);
+			debug_ptr_add(s->bev);
+			bufferevent_setcb(s->bev, socket_input_handler_bev, socket_output_handler_bev,
+				eventcb_bev, s);
+			bufferevent_setwatermark(s->bev, EV_READ|EV_WRITE, 0, BUFFEREVENT_HIGH_WATERMARK);
+			bufferevent_enable(s->bev, EV_READ|EV_WRITE); /* Start reading. */
+		}
 	}
 
 	try_start:
@@ -2303,7 +2395,7 @@ static int socket_input_worker(ioa_socket_handle s)
 	stun_buffer_list_elem *buf_elem = new_blist_elem(s->e);
 	len = -1;
 
-	if(s->bev) { /* TCP & TLS */
+	if(s->bev) { /* TCP & TLS  & SCTP & SCTP/TLS */
 		struct evbuffer *inbuf = bufferevent_get_input(s->bev);
 		if(inbuf) {
 			ev_ssize_t blen = evbuffer_copyout(inbuf, buf_elem->buf.buf, STUN_BUFFER_SIZE);
@@ -2313,7 +2405,7 @@ static int socket_input_worker(ioa_socket_handle s)
 				if(blen>(ev_ssize_t)STUN_BUFFER_SIZE)
 				  blen=(ev_ssize_t)STUN_BUFFER_SIZE;
 
-				if(((s->st == TCP_SOCKET)||(s->st == TLS_SOCKET)) && ((s->sat == TCP_CLIENT_DATA_SOCKET)||(s->sat==TCP_RELAY_DATA_SOCKET))) {
+				if(is_stream_socket(s->st) && ((s->sat == TCP_CLIENT_DATA_SOCKET)||(s->sat==TCP_RELAY_DATA_SOCKET))) {
 					mlen = blen;
 				} else {
 					mlen = stun_get_message_len_str(buf_elem->buf.buf, blen, 1, &app_msg_len);
@@ -2326,7 +2418,7 @@ static int socket_input_worker(ioa_socket_handle s)
 						s->tobeclosed = 1;
 						s->broken = 1;
 						log_socket_event(s, "socket read failed, to be closed",1);
-					} else if(s->st == TLS_SOCKET) {
+					} else if((s->st == TLS_SOCKET)||(s->st == TLS_SCTP_SOCKET)) {
 #if TLS_SUPPORTED
 						SSL *ctx = bufferevent_openssl_get_ssl(s->bev);
 						if(!ctx || SSL_get_shutdown(ctx)) {
@@ -2385,11 +2477,13 @@ static int socket_input_worker(ioa_socket_handle s)
 	}
 
 	if ((ret!=-1) && (len >= 0)) {
-		if(ioa_socket_check_bandwidth(s,(size_t)len,1)) {
-			if(app_msg_len)
-				buf_elem->buf.len = app_msg_len;
-			else
-				buf_elem->buf.len = len;
+
+		if(app_msg_len)
+			buf_elem->buf.len = app_msg_len;
+		else
+			buf_elem->buf.len = len;
+
+		if(ioa_socket_check_bandwidth(s,buf_elem,1)) {
 
 			if(s->read_cb) {
 				ioa_net_data nd;
@@ -2643,7 +2737,7 @@ static void eventcb_bev(struct bufferevent *bev, short events, void *arg)
 		if (arg) {
 			ioa_socket_handle s = (ioa_socket_handle) arg;
 
-			if((s->st != TCP_SOCKET)&&(s->st != TLS_SOCKET)&&(s->st != TENTATIVE_TCP_SOCKET)) {
+			if(!is_stream_socket(s->st)) {
 				TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO, "!!! %s: socket type is wrong on the socket: 0x%lx, st=%d, sat=%d\n",__FUNCTION__,(long)s,s->st,s->sat);
 				return;
 			}
@@ -2703,24 +2797,36 @@ static void eventcb_bev(struct bufferevent *bev, short events, void *arg)
 							addr_to_string(&(s->remote_addr),(u08bits*)sraddr);
 							if (events & BEV_EVENT_EOF) {
 								if(server->verbose)
-									TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO,"session %018llu: TCP socket closed remotely %s\n",(unsigned long long)(ss->id),sraddr);
+								  TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO,"session %018llu: %s socket closed remotely %s\n",
+										(unsigned long long)(ss->id),socket_type_name(s->st),sraddr);
 								if(s == ss->client_socket) {
-									shutdown_client_connection(server, ss, 0, "TCP connection closed by client (callback)");
+								  char msg[256];
+								  snprintf(msg,sizeof(msg)-1,"%s connection closed by client (callback)",socket_type_name(s->st));
+								  shutdown_client_connection(server, ss, 0, msg);
 								} else if(s == ss->alloc.relay_sessions[ALLOC_IPV4_INDEX].s) {
-									shutdown_client_connection(server, ss, 0, "TCP connection closed by peer (ipv4 callback)");
+								  char msg[256];
+								  snprintf(msg,sizeof(msg)-1,"%s connection closed by peer (ipv4 callback)",socket_type_name(s->st));
+								  shutdown_client_connection(server, ss, 0, msg);
 								} else if(s == ss->alloc.relay_sessions[ALLOC_IPV6_INDEX].s) {
-									shutdown_client_connection(server, ss, 0, "TCP connection closed by peer (ipv6 callback)");
+								  char msg[256];
+								  snprintf(msg,sizeof(msg)-1,"%s connection closed by peer (ipv6 callback)",socket_type_name(s->st));
+								  shutdown_client_connection(server, ss, 0, msg);
 								} else {
-									shutdown_client_connection(server, ss, 0, "TCP connection closed by remote party (callback)");
+								  char msg[256];
+								  snprintf(msg,sizeof(msg)-1,"%s connection closed by remote party (callback)",socket_type_name(s->st));
+								  shutdown_client_connection(server, ss, 0, msg);
 								}
 							} else if (events & BEV_EVENT_ERROR) {
 								if(EVUTIL_SOCKET_ERROR()) {
-									TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR,"session %018llu: TCP socket error: %s %s\n",(unsigned long long)(ss->id),
-												evutil_socket_error_to_string(EVUTIL_SOCKET_ERROR()), sraddr);
+									TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR,"session %018llu: %s socket error: %s %s\n",(unsigned long long)(ss->id),
+										      socket_type_name(s->st),evutil_socket_error_to_string(EVUTIL_SOCKET_ERROR()), sraddr);
 								} else if(server->verbose) {
-									TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO,"session %018llu: TCP socket disconnected: %s\n",(unsigned long long)(ss->id),sraddr);
+									TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO,"session %018llu: %s socket disconnected: %s\n",
+										      (unsigned long long)(ss->id),socket_type_name(s->st),sraddr);
 								}
-								shutdown_client_connection(server, ss, 0, "TCP socket buffer operation error (callback)");
+								char msg[256];
+								snprintf(msg,sizeof(msg)-1,"%s socket buffer operation error (callback)",socket_type_name(s->st));
+								shutdown_client_connection(server, ss, 0, msg);
 							 }
 						}
 					}
@@ -2966,7 +3072,7 @@ int udp_send(ioa_socket_handle s, const ioa_addr* dest_addr, const s08bits* buff
 
 int send_data_from_ioa_socket_nbh(ioa_socket_handle s, ioa_addr* dest_addr,
 				ioa_network_buffer_handle nbh,
-				int ttl, int tos)
+				int ttl, int tos, int *skip)
 {
 	int ret = -1;
 
@@ -2984,9 +3090,10 @@ int send_data_from_ioa_socket_nbh(ioa_socket_handle s, ioa_addr* dest_addr,
 		TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO, "!!! %s socket: 0x%lx was closed\n", __FUNCTION__,(long)s);
 
 	} else if (nbh) {
-		if(!ioa_socket_check_bandwidth(s,ioa_network_buffer_get_size(nbh),0)) {
+		if(!ioa_socket_check_bandwidth(s,nbh,0)) {
 			/* Bandwidth exhausted, we pretend everything is fine: */
 			ret = (int)(ioa_network_buffer_get_size(nbh));
+			if(skip) *skip = 1;
 		} else {
 			if (!ioa_socket_tobeclosed(s) && s->e) {
 
@@ -2995,7 +3102,7 @@ int send_data_from_ioa_socket_nbh(ioa_socket_handle s, ioa_addr* dest_addr,
 					set_socket_tos(s, tos);
 
 					if (s->connected && s->bev) {
-						if (s->st == TLS_SOCKET) {
+						if ((s->st == TLS_SOCKET)||(s->st == TLS_SCTP_SOCKET)) {
 #if TLS_SUPPORTED
 							SSL *ctx = bufferevent_openssl_get_ssl(s->bev);
 							if (!ctx || SSL_get_shutdown(ctx)) {
@@ -3024,6 +3131,11 @@ int send_data_from_ioa_socket_nbh(ioa_socket_handle s, ioa_addr* dest_addr,
 									s->tobeclosed = 1;
 									s->broken = 1;
 								}
+								/*
+								bufferevent_flush(s->bev,
+												EV_READ|EV_WRITE,
+												BEV_FLUSH);
+												*/
 								s->in_write = 0;
 							} else {
 								//drop the packet
@@ -3099,7 +3211,7 @@ int send_data_from_ioa_socket_tcp(ioa_socket_handle s, const void *data, size_t
 			TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO, "!!! %s socket: 0x%lx was closed\n", __FUNCTION__,(long)s);
 
 		} else if (s->connected && s->bev) {
-			if (s->st == TLS_SOCKET) {
+			if ((s->st == TLS_SOCKET)||(s->st == TLS_SCTP_SOCKET)) {
 #if TLS_SUPPORTED
 				SSL *ctx = bufferevent_openssl_get_ssl(s->bev);
 				if (!ctx || SSL_get_shutdown(ctx)) {
@@ -3172,6 +3284,7 @@ int register_callback_on_ioa_socket(ioa_engine_handle e, ioa_socket_handle s, in
 					}
 					break;
 				case TENTATIVE_TCP_SOCKET:
+				case TENTATIVE_SCTP_SOCKET:
 					if(s->bev) {
 						if(!clean_preexisting) {
 							TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR,
@@ -3189,6 +3302,7 @@ int register_callback_on_ioa_socket(ioa_engine_handle e, ioa_socket_handle s, in
 						event_add(s->read_event,NULL);
 					}
 					break;
+				case SCTP_SOCKET:
 				case TCP_SOCKET:
 					if(s->bev) {
 						if(!clean_preexisting) {
@@ -3212,6 +3326,7 @@ int register_callback_on_ioa_socket(ioa_engine_handle e, ioa_socket_handle s, in
 						}
 					}
 					break;
+				case TLS_SCTP_SOCKET:
 				case TLS_SOCKET:
 					if(s->bev) {
 						if(!clean_preexisting) {
